@@ -4,11 +4,11 @@ use abscissa_core::{Command, Options, Runnable};
 use tokio::runtime::Runtime as TokioRuntime;
 use tracing::debug;
 
-use ibc::events::IbcEventType;
-use ibc::ics02_client::client_consensus::QueryClientEventRequest;
-use ibc::ics02_client::client_state::ClientState;
-use ibc::ics24_host::identifier::ChainId;
-use ibc::ics24_host::identifier::ClientId;
+use ibc::core::ics02_client::client_consensus::QueryClientEventRequest;
+use ibc::core::ics02_client::client_state::ClientState;
+use ibc::core::ics24_host::identifier::ChainId;
+use ibc::core::ics24_host::identifier::ClientId;
+use ibc::events::WithBlockDataType;
 use ibc::query::QueryTxRequest;
 use ibc::Height;
 use ibc_proto::ibc::core::client::v1::QueryConsensusStatesRequest;
@@ -204,7 +204,7 @@ impl Runnable for QueryClientHeaderCmd {
 
         let res = chain.query_txs(QueryTxRequest::Client(QueryClientEventRequest {
             height,
-            event_id: IbcEventType::UpdateClient,
+            event_id: WithBlockDataType::UpdateClient,
             client_id: self.client_id.clone(),
             consensus_height,
         }));
