@@ -1,5 +1,5 @@
-use std::str::FromStr;
-use std::sync::Arc;
+use alloc::sync::Arc;
+use core::str::FromStr;
 
 use abscissa_core::{Command, Options, Runnable};
 use tokio::runtime::Runtime as TokioRuntime;
@@ -7,7 +7,7 @@ use tracing::debug;
 
 use tendermint::abci::transaction::Hash;
 
-use ibc::ics24_host::identifier::ChainId;
+use ibc::core::ics24_host::identifier::ChainId;
 use ibc::query::{QueryTxHash, QueryTxRequest};
 
 use ibc_relayer::chain::handle::{ChainHandle, ProdChainHandle};
