@@ -2,6 +2,7 @@ use std::io;
 
 use abscissa_core::{Component, FrameworkError, FrameworkErrorKind};
 use tracing_subscriber::{
+    filter::EnvFilter,
     fmt::{
         format::{DefaultFields, Format, Full, Json, JsonFields},
         time::SystemTime,
@@ -9,7 +10,7 @@ use tracing_subscriber::{
     },
     reload::Handle,
     util::SubscriberInitExt,
-    EnvFilter, FmtSubscriber,
+    FmtSubscriber,
 };
 
 use ibc_relayer::config::GlobalConfig;
@@ -46,6 +47,7 @@ impl JsonTracing {
             .with_env_filter(filter)
             .with_writer(std::io::stderr as StdWriter)
             .with_ansi(use_color)
+            .with_thread_ids(true)
             .json()
             .with_filter_reloading();
 
@@ -75,6 +77,7 @@ impl PrettyTracing {
             .with_env_filter(filter)
             .with_writer(std::io::stderr as StdWriter)
             .with_ansi(enable_ansi())
+            .with_thread_ids(true)
             .with_filter_reloading();
 
         let filter_handle = builder.reload_handle();
@@ -90,7 +93,7 @@ impl PrettyTracing {
 /// so that we know whether or not to enable colored output,
 /// using ANSI escape codes. If either is not, eg. because
 /// stdout is redirected to a file, we don't enable colored output.
-fn enable_ansi() -> bool {
+pub fn enable_ansi() -> bool {
     atty::is(atty::Stream::Stdout) && atty::is(atty::Stream::Stderr)
 }
 
